@@ -125,6 +125,7 @@ class LinearLR(LRSchedulerMixin, LinearParamScheduler):
 
     Notice that such decay can happen simultaneously with other changes to the
     learning rate from outside this scheduler.
+
     Args:
         optimizer (Optimizer or OptimWrapper): Wrapped optimizer.
         start_factor (float): The number we multiply learning rate in the
@@ -259,20 +260,20 @@ class OneCycleLR(LRSchedulerMixin, OneCycleParamScheduler):
         total_steps (int): The total number of steps in the cycle. Note that
             if a value is not provided here, then it must be inferred by
             providing a value for epochs and steps_per_epoch.
-            Default to None.
+            Defaults to None.
         pct_start (float): The percentage of the cycle (in number of steps)
             spent increasing the learning rate.
-            Default to 0.3
+            Defaults to 0.3
         anneal_strategy (str): {'cos', 'linear'}
             Specifies the annealing strategy: "cos" for cosine annealing,
             "linear" for linear annealing.
-            Default to 'cos'
+            Defaults to 'cos'
         div_factor (float): Determines the initial learning rate via
             initial_param = eta_max/div_factor
-            Default to 25
+            Defaults to 25
         final_div_factor (float): Determines the minimum learning rate via
             eta_min = initial_param/final_div_factor
-            Default to 1e4
+            Defaults to 1e4
         three_phase (bool): If ``True``, use a third phase of the schedule to
             annihilate the learning rate according to 'final_div_factor'
             instead of modifying the second phase (the first two phases will be
@@ -307,7 +308,7 @@ class CosineRestartLR(LRSchedulerMixin, CosineRestartParamScheduler):
             Defaults to None.
         eta_min_ratio (float, optional): The ratio of minimum parameter value
             to the base parameter value. Either `min_lr` or `min_lr_ratio`
-            should be specified. Default: None.
+            should be specified. Defaults to None.
         begin (int): Step at which to start updating the parameters.
             Defaults to 0.
         end (int): Step at which to stop updating the parameters.
