@@ -1,7 +1,12 @@
 # Copyright (c) OpenMMLab. All rights reserved.
 import os.path as osp
 import warnings
-from typing import Dict, List, Optional, Sequence, Tuple, Union
+from typing import TYPE_CHECKING, Dict, List, Optional, Sequence, Tuple, Union
+
+if TYPE_CHECKING:
+    from matplotlib.font_manager import FontProperties
+
+import logging
 
 import cv2
 import numpy as np
@@ -10,6 +15,7 @@ import torch.nn.functional as F
 
 from mmengine.config import Config
 from mmengine.dist import master_only
+from mmengine.logging import print_log
 from mmengine.registry import VISBACKENDS, VISUALIZERS
 from mmengine.structures import BaseDataElement
 from mmengine.utils import ManagerMixin
@@ -68,7 +74,7 @@ class Visualizer(ManagerMixin):
         image (np.ndarray, optional): the origin image to draw. The format
             should be RGB. Defaults to None.
         vis_backends (list, optional): Visual backend config list.
-            Default to None.
+            Defaults to None.
         save_dir (str, optional): Save file dir for all storage backends.
             If it is None, the backend storage will not save any data.
         fig_save_cfg (dict): Keyword parameters of figure for saving.
@@ -160,8 +166,11 @@ class Visualizer(ManagerMixin):
         self._vis_backends: Union[Dict, Dict[str, 'BaseVisBackend']] = dict()
 
         if save_dir is None:
-            warnings.warn('`Visualizer` backend is not initialized '
-                          'because save_dir is None.')
+            print_log(
+                '`Visualizer` backend is not initialized '
+                'because save_dir is None.',
+                logger='current',
+                level=logging.WARNING)
         elif vis_backends is not None:
             assert len(vis_backends) > 0, 'empty list'
             names = [
@@ -391,15 +400,18 @@ class Visualizer(ManagerMixin):
 
     @master_only
     def draw_texts(
-            self,
-            texts: Union[str, List[str]],
-            positions: Union[np.ndarray, torch.Tensor],
-            font_sizes: Optional[Union[int, List[int]]] = None,
-            colors: Union[str, tuple, List[str], List[tuple]] = 'g',
-            vertical_alignments: Union[str, List[str]] = 'top',
-            horizontal_alignments: Union[str, List[str]] = 'left',
-            font_families: Union[str, List[str]] = 'sans-serif',
-            bboxes: Optional[Union[dict, List[dict]]] = None) -> 'Visualizer':
+        self,
+        texts: Union[str, List[str]],
+        positions: Union[np.ndarray, torch.Tensor],
+        font_sizes: Optional[Union[int, List[int]]] = None,
+        colors: Union[str, tuple, List[str], List[tuple]] = 'g',
+        vertical_alignments: Union[str, List[str]] = 'top',
+        horizontal_alignments: Union[str, List[str]] = 'left',
+        font_families: Union[str, List[str]] = 'sans-serif',
+        bboxes: Optional[Union[dict, List[dict]]] = None,
+        font_properties: Optional[Union['FontProperties',
+                                        List['FontProperties']]] = None
+    ) -> 'Visualizer':
         """Draw single or multiple text boxes.
 
         Args:
@@ -448,7 +460,20 @@ class Visualizer(ManagerMixin):
                 the texts will have the same bbox. Reference to
                 https://matplotlib.org/stable/api/_as_gen/matplotlib.patches.FancyBboxPatch.html#matplotlib.patches.FancyBboxPatch
                 for more details. Defaults to None.
-        """
+            font_properties (Union[FontProperties, List[FontProperties]], optional):
+                The font properties of texts. FontProperties is
+                a ``font_manager.FontProperties()`` object.
+                If you want to draw Chinese texts, you need to prepare
+                a font file that can show Chinese characters properly.
+                For example: `simhei.ttf`, `simsun.ttc`, `simkai.ttf` and so on.
+                Then set ``font_properties=matplotlib.font_manager.FontProperties(fname='path/to/font_file')``
+                ``font_properties`` can have the same length with texts or
+                just single value. If ``font_properties`` is single value,
+                all the texts will have the same font properties.
+                Defaults to None.
+                `New in version 0.6.0.`
+        """  # noqa: E501
+        from matplotlib.font_manager import FontProperties
         check_type('texts', texts, (str, list))
         if isinstance(texts, str):
             texts = [texts]
@@ -489,6 +514,14 @@ class Visualizer(ManagerMixin):
                               num_text)
         font_families = value2list(font_families, str, num_text)
 
+        if font_properties is None:
+            font_properties = [None for _ in range(num_text)]  # type: ignore
+        else:
+            check_type_and_length('font_properties', font_properties,
+                                  (FontProperties, list), num_text)
+            font_properties = value2list(font_properties, FontProperties,
+                                         num_text)
+
         if bboxes is None:
             bboxes = [None for _ in range(num_text)]  # type: ignore
         else:
@@ -505,6 +538,7 @@ class Visualizer(ManagerMixin):
                 verticalalignment=vertical_alignments[i],
                 horizontalalignment=horizontal_alignments[i],
                 family=font_families[i],
+                fontproperties=font_properties[i],
                 color=colors[i])
         return self
 
@@ -608,7 +642,7 @@ class Visualizer(ManagerMixin):
                 If ``line_widths`` is single value, all the lines will
                 have the same linewidth. Defaults to 2.
             face_colors (Union[str, tuple, List[str], List[tuple]]):
-                The face colors. Default to None.
+                The face colors. Defaults to None.
             alpha (Union[int, float]): The transparency of circles.
                 Defaults to 0.8.
         """
@@ -886,7 +920,7 @@ class Visualizer(ManagerMixin):
           it will compress featmap to single channel image and weighted
           sum to `overlaid_image`.
 
-        -  if `channel_reduction` is None
+        - If `channel_reduction` is None
 
           - If topk <= 0, featmap is assert to be one or three
             channel and treated as image and will be weighted sum
@@ -899,7 +933,7 @@ class Visualizer(ManagerMixin):
             featmap (torch.Tensor): The featmap to draw which format is
                 (C, H, W).
             overlaid_image (np.ndarray, optional): The overlaid image.
-                Default to None.
+                Defaults to None.
             channel_reduction (str, optional): Reduce multiple channels to a
                 single channel. The optional value is 'squeeze_mean'
                 or 'select_max'. Defaults to 'squeeze_mean'.
@@ -910,7 +944,7 @@ class Visualizer(ManagerMixin):
             arrangement (Tuple[int, int]): The arrangement of featmap when
                 channel_reduction is not None and topk > 0. Defaults to (4, 5).
             resize_shape (tuple, optional): The shape to scale the feature map.
-                Default to None.
+                Defaults to None.
             alpha (Union[int, List[int]]): The transparency of featmap.
                 Defaults to 0.5.
 
@@ -1036,8 +1070,8 @@ class Visualizer(ManagerMixin):
         Args:
             name (str): The image identifier.
             image (np.ndarray, optional): The image to be saved. The format
-                should be RGB. Default to None.
-            step (int): Global step value to record. Default to 0.
+                should be RGB. Defaults to None.
+            step (int): Global step value to record. Defaults to 0.
         """
         for vis_backend in self._vis_backends.values():
             vis_backend.add_image(name, image, step)  # type: ignore
@@ -1053,7 +1087,7 @@ class Visualizer(ManagerMixin):
         Args:
             name (str): The scalar identifier.
             value (float, int): Value to save.
-            step (int): Global step value to record. Default to 0.
+            step (int): Global step value to record. Defaults to 0.
         """
         for vis_backend in self._vis_backends.values():
             vis_backend.add_scalar(name, value, step, **kwargs)  # type: ignore
@@ -1069,11 +1103,11 @@ class Visualizer(ManagerMixin):
         Args:
             scalar_dict (dict): Key-value pair storing the tag and
                 corresponding values.
-            step (int): Global step value to record. Default to 0.
+            step (int): Global step value to record. Defaults to 0.
             file_path (str, optional): The scalar's data will be
                 saved to the `file_path` file at the same time
                 if the `file_path` parameter is specified.
-                Default to None.
+                Defaults to None.
         """
         for vis_backend in self._vis_backends.values():
             vis_backend.add_scalars(scalar_dict, step, file_path, **kwargs)
